package App::ShellCompleter::YoutubeDl;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-09-09'; # DATE
our $DIST = 'App-ShellCompleter-YoutubeDl'; # DIST
our $VERSION = '0.122'; # VERSION

1;
# ABSTRACT: Shell completion for youtube-dl

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ShellCompleter::YoutubeDl - Shell completion for youtube-dl

=head1 VERSION

This document describes version 0.122 of App::ShellCompleter::YoutubeDl (from Perl distribution App-ShellCompleter-YoutubeDl), released on 2020-09-09.

=head1 SYNOPSIS

See L<_youtube-dl> included in this distribution.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-ShellCompleter-YoutubeDl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-ShellCompleter-YoutubeDl>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ShellCompleter-YoutubeDl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

youtube-dl, L<https://rg3.github.io/youtube-dl/>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019, 2017, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
